fhirpack.custom.extraction package — fhirpack 0.0.2b0 documentation

# fhirpack.custom.extraction package

## Submodules

## fhirpack.custom.extraction.base module

class fhirpack.custom.extraction.base.PluginBaseExtractorMixin

  Bases: `object`

  __dict__ = mappingproxy({'__module__': 'fhirpack.custom.extraction.base', 'unimplementedPluginBaseExtractorMethod': <function PluginBaseExtractorMixin.unimplementedPluginBaseExtractorMethod>, '__dict__': <attribute '__dict__' of 'PluginBaseExtractorMixin' objects>, '__weakref__': <attribute '__weakref__' of 'PluginBaseExtractorMixin' objects>, '__doc__': None, '__annotations__': {}})
  __doc__ = None
  __module__ = 'fhirpack.custom.extraction.base'
  __weakref__

    list of weak references to the object (if defined)

  unimplementedPluginBaseExtractorMethod(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, searchParams: Optional[dict] = None, params: Optional[dict] = None, ignoreFrame: bool = False)

## fhirpack.custom.extraction.sample module

class fhirpack.custom.extraction.sample.PluginSampleExtractorMixin

  Bases: `PluginBaseExtractorMixin`

  __doc__ = None
  __module__ = 'fhirpack.custom.extraction.sample'
  unimplementedPluginSampleExtractorMethod(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, searchParams: Optional[dict] = None, params: Optional[dict] = None, ignoreFrame: bool = False)

## Module contents

class fhirpack.custom.extraction.PluginExtractorMixin

  Bases: `PluginSampleExtractorMixin`

  __doc__ = None
  __module__ = 'fhirpack.custom.extraction'